@@ -613,24 +613,24 @@ GResource *libxfce4ui_get_resource (void)
 #ifdef G_HAS_CONSTRUCTORS
 
 #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
-#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
+#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(libxfce4uiresource_constructor)
 #endif
-G_DEFINE_CONSTRUCTOR(resource_constructor)
+G_DEFINE_CONSTRUCTOR(libxfce4uiresource_constructor)
 #ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
-#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
+#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(libxfce4uiresource_destructor)
 #endif
-G_DEFINE_DESTRUCTOR(resource_destructor)
+G_DEFINE_DESTRUCTOR(libxfce4uiresource_destructor)
 
 #else
 #warning "Constructor not supported on this compiler, linking in resources will not work"
 #endif
 
-static void resource_constructor (void)
+static void libxfce4uiresource_constructor (void)
 {
   g_static_resource_init (&static_resource);
 }
 
-static void resource_destructor (void)
+static void libxfce4uiresource_destructor (void)
 {
   g_static_resource_fini (&static_resource);
 }
